aboutsummaryrefslogtreecommitdiffstats
path: root/include/reddav.php
diff options
context:
space:
mode:
Diffstat (limited to 'include/reddav.php')
-rw-r--r--include/reddav.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/reddav.php b/include/reddav.php
index 750ca1b24..c39f08f4d 100644
--- a/include/reddav.php
+++ b/include/reddav.php
@@ -1,7 +1,7 @@
<?php
/**
* @file include/reddav.php
* @brief some DAV related functions for RedMatrix.
*
* This file contains some functions which did not fit into one of the RedDAV
* classes.
@@ -19,7 +19,7 @@
*/
use Sabre\DAV;
-use RedMatrix\RedDAV;
+use Hubzilla\RedDAV;
require_once('vendor/autoload.php');
require_once('include/attach.php');
@@ -1,7 +1,7 @@
/**
* @file include/reddav.php
- * @brief some DAV related functions for RedMatrix.
+ * @brief some DAV related functions for Hubzilla.
*
* This file contains some functions which did not fit into one of the RedDAV